
;********************************************************************************
;* data.s:
;*	System specific data.
;*
;*	To port gibl to another 6502 system you may need to change stuff
;*	in this file. It should be fairly obvious ...
;********************************************************************************

;********************************************************************************
;* This file is part of gibl:							*
;*	Gordons Interactive Basic Language                                      *
;********************************************************************************
;*    A Tiny Basic for the 6502 inspired by the NIBL Tiny Basic interpreter;	*
;*    "National Industrial Basic Language" originally for the INS8060 SC/MP	*
;*    system.									*
;*										*
;*    gibl is distributed under a "Source Available" license.			*
;*	It is NOT Open source and must not be treated as such.			*
;*										*
;*    See the file LICENSE for details.						*
;*										*
;*    gibl is Copyright (c) 2023 by Gordon Henderson				*
;********************************************************************************


;********************************************************************************
;* Locations of data storage:
;*	fastData is Zero page.
;*	slowData is an area RubyOS (and Acorn MOS) reserves for languages
;*	to use and is from $0400 through $07FF.
;*
;* Note that the slow area needn't be slow as such - it will all fit inside
;*	page zero if needed - especially on a "bare metal" type system - I'm
;*	running it here under Ruby OS which is modeled on Acorn MOS, so the RAM
;*	usage is very similar and Zero page from $90 through $FF is reserved
;*	for the operating system to use.
;********************************************************************************

	.include	"data.h"

;********************************************************************************
;* Zero page data (fast)
;********************************************************************************

	.segment	"ZEROPAGE":zeropage


variables	=	variablesL	; Variables; A-Z
 variablesL:	.res	varSize/2
 variablesH:	.res	varSize/2

arithStack:	.res	arithStackSize	; Arithmetic stack for variable evaluation
pcStack:	.res	pcStackSize	; The I.L. program counter stack.

doPtr:		.res	1		; DO stack pointer
forPtr:		.res	1		; FOR stack pointer
arithPtr:	.res	1		; Arithmetic stack pointer
sbrPtr:		.res	1		; GOSUB stack pointer
pcPtr:		.res	1		; I.L. Call stack pointer
pc		=	pcL		; I.L. Program counter
 pcL:		.res	1
 pcH:		.res	1
loLine:		.res	1		; Current line number
hiLine:		.res	1
runMod:		.res	1		; Run/Edit flag
pStr		=	pStrL		; Print String pointer
 pStrL:		.res	1
 pStrH:		.res	1
findlFlag:	.res	1		; Flag used in findLine

cursor		=	cursorL
  cursorL:	.res	1
  cursorH:	.res	1

svCursor	=	svCursorL
 svCursorL:	.res	1
 svCursorH:	.res	1

regA		=	regAL
 regAL:		.res	1
 regAH:		.res	1

regB		=	regBL		; GP - Also used to hold target/fail in the IL
  regBL:	.res	1
  regBH:	.res	1

regC		=	regCL		; GP - Also used to hold target/fail in the IL
  regCL:	.res	1
  regCH:	.res	1

top		=	topL		; Keeps track of the 'top' or end of the program text
 topL:		.res	1
 topH:		.res	1

num:		.res	1		; Used in ERR and compares
temp0:		.res	1		; Temporary byte store
rndX:		.res	1		; Used in the PRNG
rndY:		.res	1

osPageL:	.res	1		; Value of the start of usable program RAM.
osPageH:	.res	1

iLen:		.res	1		; Current input line length and...
cPos:		.res	1		; ... position of input line cursor

;********************************************************************************
;* Slow (non-ZP) data
;********************************************************************************

	.segment	"DATA"

sbrStack:	.res	sbrStackSize
doStack:	.res	doStackSize
forStack:	.res	forStackSize
